==> realestate-supervise-common-1.0.0-20190527.033121-2-sources.jar: cn/gtmap/realestate/supervise/qctbentity/QctbJkcxSqxx.java <==
package cn.gtmap.realestate.supervise.qctbentity;

import javax.persistence.Id;
import javax.persistence.Table;

/**
 * @author <a href="mailto:xiejianan@gtmap.cn">xiejianan</a>
 * @version 1.3, 2018/9/7 16:06
 * @description 全城通办查询接口 申请信息（即查询条件）
 */
@Table(name = "QCTB_JKCX_SQXX")
public class QctbJkcxSqxx {

    /**
     * @author juyulin
     * @description 申请信息id
     */
    @Id
    private String sqxxid;

    /**
     * @author juyulin
     * @description 查询项目id
     */
    private String cxxmid;

    /**
     * @author juyulin
     * @description 查询编号
     */
    private String cxxmbh;

    /**
     * @author juyulin
     * @description 申请人名称
     */
    private String sqrmc;

    /**
     * @author juyulin
     * @description 申请人证件号码
     */
    private String sqrzjhm;


    /**
     * @author juyulin
     * @description 查询数据所在行政区代码
     */
    private String mbxzqdm;

    /**
     * @author juyulin
     * @description 产权证类型
     */
    private String cqzlx;

    /**
     * @author juyulin
     * @description 产权证编号
     */
    private String cqzbh;


    public String getSqxxid() {
        return sqxxid;
    }

    public void setSqxxid(String sqxxid) {
        this.sqxxid = sqxxid;
    }

    public String getCxxmid() {
        return cxxmid;
    }

    public void setCxxmid(String cxxmid) {
        this.cxxmid = cxxmid;
    }

    public String getCxxmbh() {
        return cxxmbh;
    }

    public void setCxxmbh(String cxxmbh) {
        this.cxxmbh = cxxmbh;
    }

    public String getSqrmc() {
        return sqrmc;
    }

    public void setSqrmc(String sqrmc) {
        this.sqrmc = sqrmc;
    }

    public String getSqrzjhm() {
        return sqrzjhm;
    }

    public void setSqrzjhm(String sqrzjhm) {
        this.sqrzjhm = sqrzjhm;
    }

    public String getMbxzqdm() {
        return mbxzqdm;
    }

    public void setMbxzqdm(String mbxzqdm) {
        this.mbxzqdm = mbxzqdm;
    }

    public String getCqzlx() {
        return cqzlx;
    }

    public void setCqzlx(String cqzlx) {
        this.cqzlx = cqzlx;
    }

    public String getCqzbh() {
        return cqzbh;
    }

    public void setCqzbh(String cqzbh) {
        this.cqzbh = cqzbh;
    }

}

==> realestate-supervise-common-1.1.0-20251208.011103-73-sources.jar: cn/gtmap/realestate/supervise/qctbentity/QctbJkcxSqxx.java <==
package cn.gtmap.realestate.supervise.qctbentity;

import javax.persistence.Id;
import javax.persistence.Table;

/**
 * @author <a href="mailto:xiejianan@gtmap.cn">xiejianan</a>
 * @version 1.3, 2018/9/7 16:06
 * @description 全城通办查询接口 申请信息（即查询条件）
 */
@Table(name = "QCTB_JKCX_SQXX")
public class QctbJkcxSqxx {

    /**
     * @author juyulin
     * @description 申请信息id
     */
    @Id
    private String sqxxid;

    /**
     * @author juyulin
     * @description 查询项目id
     */
    private String cxxmid;

    /**
     * @author juyulin
     * @description 查询编号
     */
    private String cxxmbh;

    /**
     * @author juyulin
     * @description 申请人名称
     */
    private String sqrmc;

    /**
     * @author juyulin
     * @description 申请人证件号码
     */
    private String sqrzjhm;


    /**
     * @author juyulin
     * @description 查询数据所在行政区代码
     */
    private String mbxzqdm;

    /**
     * @author juyulin
     * @description 产权证类型
     */
    private String cqzlx;

    /**
     * @author juyulin
     * @description 产权证编号
     */
    private String cqzbh;

    /**
     * @author xiejianan
     * @description 不动产单元号
     */
    private String bdcdyh;

    /**
     * @author xiejianan
     * @description 合同编号
     */
    private String htbh;


    public String getSqxxid() {
        return sqxxid;
    }

    public void setSqxxid(String sqxxid) {
        this.sqxxid = sqxxid;
    }

    public String getCxxmid() {
        return cxxmid;
    }

    public void setCxxmid(String cxxmid) {
        this.cxxmid = cxxmid;
    }

    public String getCxxmbh() {
        return cxxmbh;
    }

    public void setCxxmbh(String cxxmbh) {
        this.cxxmbh = cxxmbh;
    }

    public String getSqrmc() {
        return sqrmc;
    }

    public void setSqrmc(String sqrmc) {
        this.sqrmc = sqrmc;
    }

    public String getSqrzjhm() {
        return sqrzjhm;
    }

    public void setSqrzjhm(String sqrzjhm) {
        this.sqrzjhm = sqrzjhm;
    }

    public String getMbxzqdm() {
        return mbxzqdm;
    }

    public void setMbxzqdm(String mbxzqdm) {
        this.mbxzqdm = mbxzqdm;
    }

    public String getCqzlx() {
        return cqzlx;
    }

    public void setCqzlx(String cqzlx) {
        this.cqzlx = cqzlx;
    }

    public String getCqzbh() {
        return cqzbh;
    }

    public void setCqzbh(String cqzbh) {
        this.cqzbh = cqzbh;
    }

    public String getBdcdyh() {
        return bdcdyh;
    }

    public void setBdcdyh(String bdcdyh) {
        this.bdcdyh = bdcdyh;
    }

    public String getHtbh() {
        return htbh;
    }

    public void setHtbh(String htbh) {
        this.htbh = htbh;
    }
}
